==> zio-aws-networkfirewall_3-5.17.166.3-sources.jar: zio/aws/networkfirewall/model/Attachment.scala <==
package zio.aws.networkfirewall.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.networkfirewall.model.primitives.{EndpointId, AzSubnet}
import scala.jdk.CollectionConverters.*
final case class Attachment(
    subnetId: Optional[AzSubnet] = Optional.Absent,
    endpointId: Optional[EndpointId] = Optional.Absent,
    status: Optional[zio.aws.networkfirewall.model.AttachmentStatus] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkfirewall.model.Attachment = {
    import Attachment.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkfirewall.model.Attachment
      .builder()
      .optionallyWith(
        subnetId.map(value => AzSubnet.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        endpointId.map(value => EndpointId.unwrap(value): java.lang.String)
      )(_.endpointId)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.networkfirewall.model.Attachment.ReadOnly =
    zio.aws.networkfirewall.model.Attachment.wrap(buildAwsValue())
}
object Attachment {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkfirewall.model.Attachment
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkfirewall.model.Attachment =
      zio.aws.networkfirewall.model.Attachment(
        subnetId.map(value => value),
        endpointId.map(value => value),
        status.map(value => value)
      )
    def subnetId: Optional[AzSubnet]
    def endpointId: Optional[EndpointId]
    def status: Optional[zio.aws.networkfirewall.model.AttachmentStatus]
    def getSubnetId: ZIO[Any, AwsError, AzSubnet] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getEndpointId: ZIO[Any, AwsError, EndpointId] =
      AwsError.unwrapOptionField("endpointId", endpointId)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.AttachmentStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkfirewall.model.Attachment
  ) extends zio.aws.networkfirewall.model.Attachment.ReadOnly {
    override val subnetId: Optional[AzSubnet] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value => zio.aws.networkfirewall.model.primitives.AzSubnet(value))
    override val endpointId: Optional[EndpointId] = zio.aws.core.internal
      .optionalFromNullable(impl.endpointId())
      .map(value => zio.aws.networkfirewall.model.primitives.EndpointId(value))
    override val status
        : Optional[zio.aws.networkfirewall.model.AttachmentStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.networkfirewall.model.AttachmentStatus.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkfirewall.model.Attachment
  ): zio.aws.networkfirewall.model.Attachment.ReadOnly = new Wrapper(impl)
}

==> zio-aws-networkfirewall_3-5.19.7.5-sources.jar: zio/aws/networkfirewall/model/Attachment.scala <==
package zio.aws.networkfirewall.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.networkfirewall.model.primitives.{
  StatusMessage,
  EndpointId,
  AzSubnet
}
import scala.jdk.CollectionConverters.*
final case class Attachment(
    subnetId: Optional[AzSubnet] = Optional.Absent,
    endpointId: Optional[EndpointId] = Optional.Absent,
    status: Optional[zio.aws.networkfirewall.model.AttachmentStatus] =
      Optional.Absent,
    statusMessage: Optional[StatusMessage] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkfirewall.model.Attachment = {
    import Attachment.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkfirewall.model.Attachment
      .builder()
      .optionallyWith(
        subnetId.map(value => AzSubnet.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        endpointId.map(value => EndpointId.unwrap(value): java.lang.String)
      )(_.endpointId)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        statusMessage.map(value =>
          StatusMessage.unwrap(value): java.lang.String
        )
      )(_.statusMessage)
      .build()
  }
  def asReadOnly: zio.aws.networkfirewall.model.Attachment.ReadOnly =
    zio.aws.networkfirewall.model.Attachment.wrap(buildAwsValue())
}
object Attachment {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkfirewall.model.Attachment
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkfirewall.model.Attachment =
      zio.aws.networkfirewall.model.Attachment(
        subnetId.map(value => value),
        endpointId.map(value => value),
        status.map(value => value),
        statusMessage.map(value => value)
      )
    def subnetId: Optional[AzSubnet]
    def endpointId: Optional[EndpointId]
    def status: Optional[zio.aws.networkfirewall.model.AttachmentStatus]
    def statusMessage: Optional[StatusMessage]
    def getSubnetId: ZIO[Any, AwsError, AzSubnet] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getEndpointId: ZIO[Any, AwsError, EndpointId] =
      AwsError.unwrapOptionField("endpointId", endpointId)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.AttachmentStatus] =
      AwsError.unwrapOptionField("status", status)
    def getStatusMessage: ZIO[Any, AwsError, StatusMessage] =
      AwsError.unwrapOptionField("statusMessage", statusMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkfirewall.model.Attachment
  ) extends zio.aws.networkfirewall.model.Attachment.ReadOnly {
    override val subnetId: Optional[AzSubnet] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value => zio.aws.networkfirewall.model.primitives.AzSubnet(value))
    override val endpointId: Optional[EndpointId] = zio.aws.core.internal
      .optionalFromNullable(impl.endpointId())
      .map(value => zio.aws.networkfirewall.model.primitives.EndpointId(value))
    override val status
        : Optional[zio.aws.networkfirewall.model.AttachmentStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.networkfirewall.model.AttachmentStatus.wrap(value)
        )
    override val statusMessage: Optional[StatusMessage] = zio.aws.core.internal
      .optionalFromNullable(impl.statusMessage())
      .map(value =>
        zio.aws.networkfirewall.model.primitives.StatusMessage(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkfirewall.model.Attachment
  ): zio.aws.networkfirewall.model.Attachment.ReadOnly = new Wrapper(impl)
}
